![SIF](https://img.shields.io/badge/NSF_NCAR-CGD_SIF-blue)
![NSF](https://img.shields.io/badge/NSF-220777-blue)
![NSF](https://img.shields.io/badge/NSF-2530608-blue)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17028522.svg)](https://doi.org/10.5281/zenodo.17028522)
[![PyPI version](https://badge.fury.io/py/x4c.svg)](https://badge.fury.io/py/x4c)
[![PyPI](https://img.shields.io/badge/python-3.12-blue.svg)]()
[![PyPI](https://img.shields.io/badge/python-3.13-blue.svg)]()
[![license](https://img.shields.io/github/license/NCAR/x4c.svg)]()

# x4c: Xarray for CESM
> [!NOTE]
> If you use `x4c` in any way for your publications, please cite:
> 
> + Zhu, F., Levy, M., & Dobbins, B. (2025). x4c: Xarray for efficient CESM postprocessing, analysis, and visualization. Zenodo. https://doi.org/10.5281/zenodo.17028522

`x4c` is an Xarray extension that aims to support efficient and intuitive CESM output postprocessing, analysis, and visualization:
- Postprocessing features: time series generation, seasonal cycle climatology generation, etc.
- Analysis features: regrid, various of mean calculation, annualization/seasonalization, etc.
- Visualization features: timeseries, horizontal and vertical 2D spatial plots, etc.

> **_Disclaimer:_**  This package is still in its early stage and under active development, and its API could be changed frequently.

For more details, please refer to the documentation linked below.

## Documentation

+ Homepage: https://NCAR.github.io/x4c
+ Installation: https://NCAR.github.io/x4c/ug-installation.html